from distutils.core import setup

setup(
    name='tweeterid',
    version='1.0.0',
    description='Get twitter handles based on user ID\'s and vice-versa via tweeterid.com in python',
    long_description='Get twitter handles based on user ID\'s and vice-versa via tweeterid.com in python',
    author='sl4v',
    author_email='iamsl4v@protonmail.com',
    url='https://github.com/sl4vkek/python-tweeterid',
    packages=['tweeterid'],
    install_requires=['requests'],
    license="WTFPL"
)
